import tkinter as tk

import product11 as p


class GUI:
    def __init__(self, product_name, products, extras):
        self.product_name = product_name
        self.products = products
        self.extras = extras

        window = tk.Tk()
        window.geometry("500x600")
        window.title(f"Python {product_name}s")

        self.basket = []

        row_counter = 0

        lbl0 = tk.Label(window, text=f"{product_name}s", font=("Arial Bold", 20))
        lbl0.grid(column=0, row=row_counter, sticky="W")
        row_counter += 1

        self.chosen = tk.StringVar(window)
        self.chosen.set(list(products)[0])

        for product in products:
            rad = tk.Radiobutton(window, text=f"{product} - £{products[product]:.2f}", value=product,
                                 variable=self.chosen,
                                 command=self.respond)
            rad.grid(column=0, row=row_counter, sticky="W")
            row_counter += 1

        lbl1 = tk.Label(window, text="Extras", font=("Arial Bold", 20))
        lbl1.grid(column=0, row=row_counter, sticky="W")
        row_counter += 1

        self.extra_chosen = {}
        for extra in extras:
            self.extra_chosen[extra] = tk.BooleanVar(window)
            chk = tk.Checkbutton(window, text=f"{extra} - £{extras[extra]:.2f}", var=self.extra_chosen[extra],
                                 command=self.respond)
            chk.grid(column=0, row=row_counter, sticky="W")
            row_counter += 1

        self.txt_output = tk.StringVar(window)

        txt = tk.Entry(window, width=25, textvariable=self.txt_output, state="readonly")
        txt.grid(column=0, row=row_counter, sticky="W", padx=5, pady=5)
        row_counter += 1

        add_button = tk.Button(window, text="Add to basket", command=self.add_to_basket)
        add_button.grid(column=0, row=row_counter, sticky="W", padx=5, pady=5)

        empty_button = tk.Button(window, text="Empty basket", command=self.empty_basket)
        empty_button.grid(column=1, row=row_counter, sticky="W", padx=5, pady=5)
        row_counter += 1

        lbl1 = tk.Label(window, text="Basket", font=("Arial Bold", 20))
        lbl1.grid(column=0, row=row_counter, sticky="W")
        row_counter += 1

        self.txt2 = tk.Text(window, width=60, height=10, state="disabled")
        self.txt2.grid(column=0, row=row_counter, columnspan=2, sticky="W", padx=5, pady=5)
        row_counter += 1

        self.basket_output = tk.StringVar(window)

        self.txt3 = tk.Entry(window, width=25, textvariable=self.basket_output, state="readonly")
        self.txt3.grid(column=0, row=row_counter, sticky="W", padx=5, pady=5)
        row_counter += 1

        self.respond()

        window.mainloop()

    def respond(self):
        product_type = self.chosen.get()
        product_price = self.products[product_type]
        description = product_type
        extras_description = ""
        for extra in self.extras:
            if self.extra_chosen[extra].get():
                if extras_description == "":
                    extras_description += f" with extra {extra}"
                else:
                    extras_description += f", {extra}"
                product_price += self.extras[extra]
        description += extras_description
        print(f"{self.product_name} chosen is {description}")
        self.txt_output.set(f"{self.product_name} price is £{product_price:.2f}")

    def add_to_basket(self):
        product_type = self.chosen.get()
        product_price = self.products[product_type]
        chosen_product = p.Product(product_type, product_price)
        for extra in self.extras:
            if self.extra_chosen[extra].get():
                extra_price = self.extras[extra]
                chosen_product.add_extra(extra, extra_price)
        self.basket.append(chosen_product)
        self.set_basket_contents()

    def empty_basket(self):
        self.basket.clear()
        self.set_basket_contents()

    def set_basket_contents(self):
        self.txt2["state"] = "normal"
        self.txt2.delete("1.0", tk.END)
        contents = ""
        total_cost = 0
        for chosen_product in self.basket:
            contents += chosen_product.get_description() + "\n"
            total_cost += chosen_product.price
        self.txt2.insert(1.0, contents)
        self.txt2["state"] = "disabled"
        self.basket_output.set(f"Total cost is £{total_cost:.2f}")
